@@ -1,6 +1,7 @@
 
 using System;
 using System.Collections;
+using System.Collections.Generic;
 
 using NDesk.DBus;
 using org.freedesktop.DBus;
@@ -36,7 +37,7 @@ namespace Tomboy
 		{
 			return Defines.VERSION;
 		}
-	
+
 		public bool DisplayNote (string uri)
 		{
 			Note note;
@@ -73,7 +74,7 @@ namespace Tomboy
 			Note note = note_manager.Find (linked_title);
 			return (note == null) ? String.Empty : note.Uri;
 		}
-		
+
 		public string FindStartHereNote ()
 		{
 			Note note = note_manager.FindByUri (NoteManager.StartNoteUri);
@@ -86,14 +87,14 @@ namespace Tomboy
 				Note note = note_manager.Create ();
 				return note.Uri;
 			} catch {
-				return  "";
-			}
+			return  "";
 		}
+	}
 
-		public string CreateNamedNote (string linked_title)
+	public string CreateNamedNote (string linked_title)
 		{
 			Note note;
-			
+
 			note = note_manager.Find (linked_title);
 			if (note != null)
 				return "";
@@ -102,11 +103,11 @@ namespace Tomboy
 				note = note_manager.Create (linked_title);
 				return note.Uri;
 			} catch {
-				return "";
-			}
+			return "";
 		}
+	}
 
-		public bool DeleteNote (string uri)
+	public bool DeleteNote (string uri)
 		{
 			Note note;
 
@@ -117,19 +118,19 @@ namespace Tomboy
 			note_manager.Delete (note);
 			return true;
 		}
-		
+
 		public void DisplaySearch ()
 		{
 			NoteRecentChanges.GetInstance (note_manager).Present ();
 		}
-		
+
 		public void DisplaySearchWithText (string search_text)
 		{
 			NoteRecentChanges recent_changes =
-				NoteRecentChanges.GetInstance (note_manager);
+			        NoteRecentChanges.GetInstance (note_manager);
 			if (recent_changes == null)
 				return;
-			
+
 			recent_changes.SearchText = search_text;
 			recent_changes.Present ();
 		}
@@ -193,7 +194,7 @@ namespace Tomboy
 				return "";
 			return note.XmlContent;
 		}
-		
+
 		public string GetNoteCompleteXml (string uri)
 		{
 			Note note;
@@ -222,7 +223,7 @@ namespace Tomboy
 			note.XmlContent = xml_contents;
 			return true;
 		}
-		
+
 		/// <summary>
 		/// Reset the entire XML data for the given note.
 		/// NOTE: Throws exception if xml_contents is invalid.
@@ -247,7 +248,7 @@ namespace Tomboy
 				tags [i] = note.Tags [i].NormalizedName;
 			return tags;
 		}
-		
+
 		public bool AddTagToNote (string uri, string tag_name)
 		{
 			Note note = note_manager.FindByUri (uri);
@@ -257,7 +258,7 @@ namespace Tomboy
 			note.AddTag (tag);
 			return true;
 		}
-		
+
 		public bool RemoveTagFromNote (string uri, string tag_name)
 		{
 			Note note = note_manager.FindByUri (uri);
@@ -268,7 +269,7 @@ namespace Tomboy
 				note.RemoveTag (tag);
 			return true;
 		}
-		
+
 		public string[] GetAllNotesWithTag (string tag_name)
 		{
 			Tag tag = TagManager.GetTag (tag_name);
@@ -298,6 +299,21 @@ namespace Tomboy
 				NoteSaved (note.Uri);
 		}
 
+		public string[] SearchNotes (string query, bool case_sensitive)
+		{
+			if (query == null)
+				return null;
+
+			Search search =  new Search(note_manager);
+			List<string> list = new List<string>();
+			IDictionary<Note,int> results =
+				search.SearchNotes(query, case_sensitive);
+			foreach (Note note in results.Keys) {
+				list.Add (note.Uri);
+			}
+			return list.ToArray ();
+		}
+
 		public event RemoteDeletedHandler NoteDeleted;
 		public event RemoteAddedHandler NoteAdded;
 		public event RemoteSavedHandler NoteSaved;
