@@ -9,33 +9,35 @@ namespace Tomboy.Sync
 {
 	public abstract class FuseSyncServiceAddin : SyncServiceAddin
 	{
-#region Private Data
-		private string mountPath;		
+		#region Private Data
+		private string mountPath;
 		private InterruptableTimeout unmountTimeout;
-		
+
 		private string fuseMountExePath;
 		private string fuseUnmountExePath;
 		private string mountExePath;
 		private bool initialized = false;
-#endregion // Private Data
+		#endregion // Private Data
 
-#region SyncServiceAddin Overrides
+		#region SyncServiceAddin Overrides
 		public override void Shutdown ()
 		{
 			// TODO: Consider replacing TomboyExitHandler with this!
 		}
-		
+
 		public override bool Initialized {
-			get { return initialized; }
+			get {
+				return initialized;
+			}
 		}
-		
+
 		public override void Initialize ()
 		{
 			// TODO: When/how best to handle this?  Okay to install wdfs while Tomboy is running?  When set up mount path, timer, etc, then?
 			if (IsSupported) {
 				// Determine mount path, etc
 				SetUpMountPath ();
-				
+
 				// Setup unmount timer
 				unmountTimeout = new InterruptableTimeout ();
 				unmountTimeout.Timeout += UnmountTimeout;
@@ -47,10 +49,10 @@ namespace Tomboy.Sync
 		public override SyncServer CreateSyncServer ()
 		{
 			SyncServer server = null;
-			
+
 			// Cancel timer
 			unmountTimeout.Cancel ();
-			
+
 			// Mount if necessary
 			if (IsConfigured) {
 				if (!IsMounted && !MountFuse (true)) // MountFuse may throw TomboySyncException!
@@ -58,11 +60,11 @@ namespace Tomboy.Sync
 				server = new FileSystemSyncServer (mountPath);
 			} else
 				throw new InvalidOperationException ("CreateSyncServer called without being configured");
-			
+
 			// Return FileSystemSyncServer
 			return server;
 		}
-		
+
 		public override void PostSyncCleanup ()
 		{
 			// Set unmount timeout to 5 minutes or something
@@ -77,27 +79,27 @@ namespace Tomboy.Sync
 				fuseMountExePath = SyncUtils.FindFirstExecutableInPath (FuseMountExeName);
 				fuseUnmountExePath = SyncUtils.FindFirstExecutableInPath ("fusermount");
 				mountExePath = SyncUtils.FindFirstExecutableInPath ("mount");
-				
+
 				return !string.IsNullOrEmpty (fuseMountExePath) &&
-					!string.IsNullOrEmpty (fuseUnmountExePath) &&
-						!string.IsNullOrEmpty (mountExePath);
+				       !string.IsNullOrEmpty (fuseUnmountExePath) &&
+				       !string.IsNullOrEmpty (mountExePath);
 			}
 		}
-		
+
 		public override bool SaveConfiguration ()
 		{
 			// TODO: When/how best to handle this?
 			if (!IsSupported)
 				throw new TomboySyncException (string.Format (Catalog.GetString ("This synchronization addin is not supported on your computer. " +
-				                                                                 "Please make sure you have FUSE and {0} correctly installed and configured"),
-				                                              FuseMountExeName));
+				                               "Please make sure you have FUSE and {0} correctly installed and configured"),
+				                               FuseMountExeName));
 
 			if (!VerifyConfiguration ())
 				return false;
-			
+
 			// TODO: Check to see if the mount is already mounted
 			bool mounted = MountFuse (false);
-			
+
 			if (mounted) {
 				try {
 					// Test creating/writing/deleting a file
@@ -105,67 +107,68 @@ namespace Tomboy.Sync
 					string testPathBase = Path.Combine (mountPath, "test");
 					string testPath = testPathBase;
 					int count = 0;
-					
+
 					// Get unique new file name
 					while (File.Exists (testPath))
 						testPath = testPathBase + (++count).ToString ();
-					
+
 					// Test ability to create and write
 					string testLine = "Testing write capabilities.";
 					using (FileStream fs = File.Create (testPath)) {
 						StreamWriter writer = new StreamWriter (fs);
 						writer.WriteLine (testLine);
 					}
-					
+
 					// Test ability to read
 					bool testFileFound = false;
 					foreach (string filePath in Directory.GetFiles (mountPath))
-						if (filePath == testPath) {
-							testFileFound = true;
-							break;
-						}
+					if (filePath == testPath) {
+						testFileFound = true;
+						break;
+					}
 					if (!testFileFound)
 						; // TODO: Throw TomboySyncException
 					using (StreamReader reader = new StreamReader (testPath)) {
 						if (reader.ReadLine () != testLine)
 							; // TODO: Throw TomboySyncException
 					}
-					
+
 					// Test ability to delete
 					File.Delete (testPath);
 				} finally {
 					// Clean up
 					PostSyncCleanup ();
 				}
-					
+
 				// Finish save process
 				SaveConfigurationValues ();
 			}
-			
+
 			return mounted;
 		}
-		
+
 		public override void ResetConfiguration ()
 		{
 			// Unmount immediately, then reset configuration
 			UnmountTimeout (this, null);
 			ResetConfigurationValues ();
 		}
-#endregion // SyncServiceAddin Overrides
+		#endregion // SyncServiceAddin Overrides
 
-#region Abstract Members
+		#region Abstract Members
 		protected abstract bool VerifyConfiguration ();
-		
-		protected abstract void SaveConfigurationValues ();
-		
-		protected abstract void ResetConfigurationValues ();
-		
-		protected abstract string FuseMountExeName { get; }
-		
-		protected abstract string GetFuseMountExeArgs (string mountPath, bool fromStoredValues);
-#endregion // Abstract Members
 
-#region Public Virtual Members
+		protected abstract void SaveConfigurationValues ();
+
+		protected abstract void ResetConfigurationValues ();
+
+		protected abstract string FuseMountExeName { get;
+			                                           }
+
+			protected abstract string GetFuseMountExeArgs (string mountPath, bool fromStoredValues);
+		#endregion // Abstract Members
+
+		#region Public Virtual Members
 		public virtual string FuseMountTimeoutError
 		{
 			get
@@ -173,7 +176,7 @@ namespace Tomboy.Sync
 				return Catalog.GetString ("Timeout connecting to server.");
 			}
 		}
-		
+
 		public virtual string FuseMountDirectoryError
 		{
 			get
@@ -181,31 +184,31 @@ namespace Tomboy.Sync
 				return Catalog.GetString ("Error connecting to server.");
 			}
 		}
-#endregion
+		#endregion
 
-#region Private Methods
+		#region Private Methods
 		private bool MountFuse (bool useStoredValues)
 		{
 			if (string.IsNullOrEmpty (mountPath))
 				return false;
-			
+
 			if (SyncUtils.IsFuseEnabled () == false) {
 				if (SyncUtils.EnableFuse () == false) {
 					Logger.Debug ("User canceled or something went wrong enabling FUSE");
 					throw new TomboySyncException (Catalog.GetString ("FUSE could not be enabled."));
 				}
 			}
-			
+
 			PrepareMountPath ();
 
 			Process p = new Process ();
-			
+
 			// Need to redirect stderr for displaying errors to user,
 			// but we can't use stdout and by not redirecting it, it
 			// should appear in the console Tomboy is started from.
 			p.StartInfo.RedirectStandardOutput = false;
 			p.StartInfo.RedirectStandardError = true;
-			
+
 			p.StartInfo.UseShellExecute = false;
 			p.StartInfo.FileName = fuseMountExePath;
 			p.StartInfo.Arguments = GetFuseMountExeArgs (mountPath, useStoredValues);
@@ -225,7 +228,7 @@ namespace Tomboy.Sync
 				throw new TomboySyncException (Catalog.GetString ("An error ocurred while connecting to the specified server:") +
 				                               "\n\n" + p.StandardError.ReadToEnd ());
 			}
-			
+
 			// For wdfs, incorrect user credentials will cause the mountPath to
 			// be messed up, and not recognized as a directory.  This is the only
 			// way I can find to report that the username/password may be incorrect (for wdfs).
@@ -239,16 +242,16 @@ namespace Tomboy.Sync
 				UnmountTimeout (null, null); // TODO: This is awfully ugly
 				throw new TomboySyncException (FuseMountDirectoryError);
 			}
-			
+
 			return true;
 		}
-		
+
 		private void SetUpMountPath ()
 		{
 			string notesPath = Tomboy.DefaultNoteManager.NoteDirectoryPath;
 			mountPath = Path.Combine (notesPath, "sync-" + Id); // TODO: Best mount path name?
 		}
-		
+
 		private void PrepareMountPath ()
 		{
 			if (Directory.Exists (mountPath) == false) {
@@ -256,18 +259,18 @@ namespace Tomboy.Sync
 					Directory.CreateDirectory (mountPath);
 				} catch (Exception e) {
 					throw new Exception (
-						string.Format (
-							"Couldn't create \"{0}\" directory: {1}",
-							mountPath, e.Message));
+					        string.Format (
+					                "Couldn't create \"{0}\" directory: {1}",
+					                mountPath, e.Message));
 				}
 			} else
 				// Just in case, make sure there is no
 				// existing FUSE mount at mountPath.
 				UnmountTimeout (null, null);
 		}
-		
-		//private bool 
-		
+
+		//private bool
+
 		/// <summary>
 		/// Perform clean up when Tomboy exits.
 		/// </summary>
@@ -277,7 +280,7 @@ namespace Tomboy.Sync
 			//       directly to the Tomboy.Exiting event?
 			UnmountTimeout (sender, e);
 		}
-		
+
 		private void UnmountTimeout (object sender, System.EventArgs e)
 		{
 			if (IsMounted)
@@ -287,13 +290,13 @@ namespace Tomboy.Sync
 				p.StartInfo.RedirectStandardOutput = false;
 				p.StartInfo.FileName = fuseUnmountExePath;
 				p.StartInfo.Arguments =
-					string.Format (
-						"-u {0}",
-						mountPath);
+				        string.Format (
+				                "-u {0}",
+				                mountPath);
 				p.StartInfo.CreateNoWindow = true;
 				p.Start ();
 				p.WaitForExit ();
-				
+
 				// TODO: What does this return if it was not mounted?
 				if (p.ExitCode == 1) {
 					Logger.Debug ("Error unmounting " + Id);
@@ -305,7 +308,7 @@ namespace Tomboy.Sync
 				}
 			}
 		}
-		
+
 		/// <summary>
 		/// Checks to see if the mount is actually mounted and alive
 		/// </summary>
@@ -326,21 +329,21 @@ namespace Tomboy.Sync
 					outputLines.Add (line);
 				}
 				p.WaitForExit ();
-				
+
 				if (p.ExitCode == 1) {
 					Logger.Debug ("Error calling " + mountExePath);
 					return false;
 				}
-				
+
 				// TODO: Review this methodology...is it really the exe name, for example?
 				foreach (string outputLine in outputLines)
-					if (outputLine.StartsWith (FuseMountExeName) &&
-					    outputLine.IndexOf (string.Format ("on {0} ", mountPath)) > -1)
-						return true;
-				
+				if (outputLine.StartsWith (FuseMountExeName) &&
+				                outputLine.IndexOf (string.Format ("on {0} ", mountPath)) > -1)
+					return true;
+
 				return false;
 			}
 		}
-#endregion // Private Methods
+		#endregion // Private Methods
 	}
 }
