@@ -30,7 +30,7 @@ namespace Tomboy
 		}
 
 		public NoteMenuItem (Note note, bool show_pin)
-			: base (GetDisplayName(note))
+: base (GetDisplayName(note))
 		{
 			this.note = note;
 			Image = new Gtk.Image (note_icon);
@@ -65,7 +65,7 @@ namespace Tomboy
 			return FormatForLabel (display_name);
 		}
 
-		protected override void OnActivated () 
+		protected override void OnActivated ()
 		{
 			if (!inhibit_activate) {
 				if (note != null)
@@ -76,8 +76,8 @@ namespace Tomboy
 		protected override bool OnButtonPressEvent (Gdk.EventButton ev)
 		{
 			if (pin_img != null &&
-			    ev.X >= pin_img.Allocation.X && 
-			    ev.X < pin_img.Allocation.X + pin_img.Allocation.Width) {
+			                ev.X >= pin_img.Allocation.X &&
+			                ev.X < pin_img.Allocation.X + pin_img.Allocation.Width) {
 				pinned = note.IsPinned = !pinned;
 				pin_img.Pixbuf = pinned ? pindown : pinup;
 				inhibit_activate = true;
@@ -98,8 +98,8 @@ namespace Tomboy
 		protected override bool OnMotionNotifyEvent (Gdk.EventMotion ev)
 		{
 			if (!pinned && pin_img != null) {
-				if (ev.X >= pin_img.Allocation.X && 
-				    ev.X < pin_img.Allocation.X + pin_img.Allocation.Width) {
+				if (ev.X >= pin_img.Allocation.X &&
+				                ev.X < pin_img.Allocation.X + pin_img.Allocation.Width) {
 					if (pin_img.Pixbuf != pinup_active)
 						pin_img.Pixbuf = pinup_active;
 				} else if (pin_img.Pixbuf != pinup) {
@@ -114,12 +114,12 @@ namespace Tomboy
 			if (!pinned && pin_img != null) {
 				pin_img.Pixbuf = pinup;
 			}
-			return base.OnLeaveNotifyEvent (ev);			
+			return base.OnLeaveNotifyEvent (ev);
 		}
 	}
 
 	public enum PanelOrientation { Horizontal, Vertical };
-	
+
 	public class TomboyTray : Gtk.EventBox
 	{
 		NoteManager manager;
@@ -130,8 +130,8 @@ namespace Tomboy
 		List<Gtk.MenuItem> recent_notes = new List<Gtk.MenuItem> ();
 		int panel_size;
 
-		public TomboyTray (NoteManager manager) 
-			: base ()
+		public TomboyTray (NoteManager manager)
+: base ()
 		{
 			this.manager = manager;
 			// Load a 16x16-sized icon to ensure we don't end up with a
@@ -147,9 +147,9 @@ namespace Tomboy
 			string tip_text = Catalog.GetString ("Tomboy Notes");
 
 			if ((bool) Preferences.Get (Preferences.ENABLE_KEYBINDINGS)) {
-				string shortcut = 
-					GConfKeybindingToAccel.GetShortcut (
-						Preferences.KEYBINDING_SHOW_NOTE_MENU);
+				string shortcut =
+				        GConfKeybindingToAccel.GetShortcut (
+				                Preferences.KEYBINDING_SHOW_NOTE_MENU);
 				if (shortcut != null)
 					tip_text += String.Format (" ({0})", shortcut);
 			}
@@ -158,14 +158,14 @@ namespace Tomboy
 			tips.SetTip (this, tip_text, null);
 			tips.Enable ();
 			tips.Sink ();
-			
+
 			SetupDragAndDrop ();
-			
+
 			recent_menu = MakeRecentNotesMenu ();
 			recent_menu.Hidden += MenuHidden;
 		}
 
-		void ButtonPress (object sender, Gtk.ButtonPressEventArgs args) 
+		void ButtonPress (object sender, Gtk.ButtonPressEventArgs args)
 		{
 			Gtk.Widget parent = (Gtk.Widget) sender;
 
@@ -230,73 +230,82 @@ namespace Tomboy
 
 			if (text == null || text.Trim() == string.Empty)
 				return false;
-			
+
 			Note link_note = manager.FindByUri (NoteManager.StartNoteUri);
 			if (link_note == null)
 				return false;
 
 			link_note.Window.Present ();
-			PrependTimestampedText (link_note, 
-						DateTime.Now, 
-						text);
+			PrependTimestampedText (link_note,
+			                        DateTime.Now,
+			                        text);
 
 			return true;
 		}
-		
+
 		Gtk.Menu MakeRecentNotesMenu ()
 		{
 			Gtk.Menu menu =
-				Tomboy.ActionManager.GetWidget ("/TrayIconMenu") as Gtk.Menu;
-			
-			bool enable_keybindings = (bool) 
-				Preferences.Get (Preferences.ENABLE_KEYBINDINGS);
+			        Tomboy.ActionManager.GetWidget ("/TrayIconMenu") as Gtk.Menu;
+
+			bool enable_keybindings = (bool)
+			                          Preferences.Get (Preferences.ENABLE_KEYBINDINGS);
 			if (enable_keybindings) {
 				// Create New Note Keybinding
 				Gtk.MenuItem item =
-					Tomboy.ActionManager.GetWidget (
-						"/TrayIconMenu/NewNote") as Gtk.MenuItem;
+				        Tomboy.ActionManager.GetWidget (
+				                "/TrayIconMenu/NewNote") as Gtk.MenuItem;
 				if (item != null)
 					GConfKeybindingToAccel.AddAccelerator (
-						item,
-						Preferences.KEYBINDING_CREATE_NEW_NOTE);
-				
+					        item,
+					        Preferences.KEYBINDING_CREATE_NEW_NOTE);
+
 				// Show Search All Notes Keybinding
 				item =
-					Tomboy.ActionManager.GetWidget (
-						"/TrayIconMenu/ShowSearchAllNotes") as Gtk.MenuItem;
+				        Tomboy.ActionManager.GetWidget (
+				                "/TrayIconMenu/ShowSearchAllNotes") as Gtk.MenuItem;
 				if (item != null)
 					GConfKeybindingToAccel.AddAccelerator (
-						item,
-						Preferences.KEYBINDING_CREATE_NEW_NOTE);
-				
-				// Open Start Here Keybinding			
+					        item,
+					        Preferences.KEYBINDING_CREATE_NEW_NOTE);
+
+				// Open Start Here Keybinding
 				item =
-					Tomboy.ActionManager.GetWidget (
-						"/TrayIconMenu/OpenStartHereNote") as Gtk.MenuItem;
+				        Tomboy.ActionManager.GetWidget (
+				                "/TrayIconMenu/OpenStartHereNote") as Gtk.MenuItem;
 				if (item != null)
 					GConfKeybindingToAccel.AddAccelerator (
-						item,
-						Preferences.KEYBINDING_OPEN_RECENT_CHANGES);
-			}				
-			
+					        item,
+					        Preferences.KEYBINDING_OPEN_RECENT_CHANGES);
+			}
+
 			return menu;
 		}
-		
+
 		void MenuHidden (object sender, EventArgs args)
 		{
 			// Remove the old dynamic items
 			RemoveRecentlyChangedNotes ();
 		}
-		
+
 		void AddRecentlyChangedNotes ()
 		{
 			int min_size = (int) Preferences.Get (Preferences.MENU_NOTE_COUNT);
 			int max_size = 18;
 			int list_size = 0;
+			bool menuOpensUpward = MenuOpensUpward ();
 			NoteMenuItem item;
 
+			// Assume menu opens downward, move common items to top of menu
+			Gtk.MenuItem newNoteItem = Tomboy.ActionManager.GetWidget (
+			                                   "/TrayIconMenu/TrayNewNote") as Gtk.MenuItem;
+			Gtk.MenuItem searchNotesItem = Tomboy.ActionManager.GetWidget (
+			                                       "/TrayIconMenu/ShowSearchAllNotes") as Gtk.MenuItem;
+			recent_menu.ReorderChild (newNoteItem, 0);
+			recent_menu.ReorderChild (searchNotesItem, 1);
+
 			DateTime days_ago = DateTime.Today.AddDays (-3);
-			
+
 			// List the i most recently changed notes, any currently
 			// opened notes, and any pinned notes...
 			foreach (Note note in manager.Notes) {
@@ -304,23 +313,26 @@ namespace Tomboy
 					continue;
 
 				bool show = false;
-				
-				if ((note.IsOpened && note.Window.IsMapped) ||
-				    note.ChangeDate > days_ago ||
-				    list_size < min_size) {
+
+				// Test for note.IsPinned first so that all of the pinned notes
+				// are guaranteed to be included regardless of the size of the
+				// list.
+				if (note.IsPinned) {
+					show = true;
+				} else if ((note.IsOpened && note.Window.IsMapped) ||
+				                note.ChangeDate > days_ago ||
+				                list_size < min_size) {
 					if (list_size <= max_size)
 						show = true;
-				} else if (note.IsPinned) {
-					show = true;
 				}
 
 				if (show) {
 					item = new NoteMenuItem (note, true);
-					// Add this widget to the menu (+2 to add after separator)
+					// Add this widget to the menu (+2 to add after new+search)
 					recent_menu.Insert (item, list_size + 2);
 					// Keep track of this item so we can remove it later
 					recent_notes.Add (item);
-					
+
 					list_size++;
 				}
 			}
@@ -328,49 +340,71 @@ namespace Tomboy
 			Note start = manager.FindByUri (NoteManager.StartNoteUri);
 			if (start != null) {
 				item = new NoteMenuItem (start, false);
-				recent_menu.Insert (item, list_size + 2);
+				if (menuOpensUpward)
+					recent_menu.Insert (item, list_size + 2);
+				else
+					recent_menu.Insert (item, 2);
 				recent_notes.Add (item);
 
 				list_size++;
 
-				bool enable_keybindings = (bool) 
-					Preferences.Get (Preferences.ENABLE_KEYBINDINGS);
+				bool enable_keybindings = (bool)
+				                          Preferences.Get (Preferences.ENABLE_KEYBINDINGS);
 				if (enable_keybindings)
 					GConfKeybindingToAccel.AddAccelerator (
-						item, 
-						Preferences.KEYBINDING_OPEN_START_HERE);
+					        item,
+					        Preferences.KEYBINDING_OPEN_START_HERE);
 			}
-			
+
+			int insertion_point = 2; // If menu opens downard
+
+			// FIXME: Rearrange this stuff to have less wasteful reordering
+			if (menuOpensUpward) {
+				// Relocate common items to bottom of menu
+				recent_menu.ReorderChild (searchNotesItem, list_size + 1);
+				recent_menu.ReorderChild (newNoteItem, list_size + 1);
+				insertion_point = list_size;
+			}
+
 			Gtk.SeparatorMenuItem separator = new Gtk.SeparatorMenuItem ();
-			recent_menu.Insert (separator, list_size + 2);
+			recent_menu.Insert (separator, insertion_point);
 			recent_notes.Add (separator);
 		}
-		
+
+		bool MenuOpensUpward ()
+		{
+			int x, y;
+			this.GdkWindow.GetOrigin (out x, out y);
+			return y > 100; // FIXME: This can be better, I'm sure
+		}
+
 		void RemoveRecentlyChangedNotes ()
 		{
 			foreach (Gtk.Widget item in recent_notes) {
 				recent_menu.Remove (item);
 			}
-			
+
 			recent_notes.Clear ();
 		}
-		
-		void UpdateRecentNotesMenu (Gtk.Widget parent) 
+
+		void UpdateRecentNotesMenu (Gtk.Widget parent)
 		{
 			if (!menu_added) {
 				recent_menu.AttachToWidget (parent, GuiUtils.DetachMenu);
 				menu_added = true;
 			}
-			
+
 			AddRecentlyChangedNotes ();
 
 			recent_menu.ShowAll ();
 		}
-		
+
 		// Used by TomboyApplet to modify the icon background.
 		public Gtk.Image Image
 		{
-			get { return image; }
+			get {
+				return image;
+			}
 		}
 
 		public void ShowMenu (bool select_first_item)
@@ -385,24 +419,24 @@ namespace Tomboy
 		// Support dropping text/uri-lists and _NETSCAPE_URLs currently.
 		void SetupDragAndDrop ()
 		{
-			Gtk.TargetEntry [] targets = 
-				new Gtk.TargetEntry [] {
-					new Gtk.TargetEntry ("text/uri-list", 0, 0),
-					new Gtk.TargetEntry ("_NETSCAPE_URL", 0, 0)
-				};
+			Gtk.TargetEntry [] targets =
+			new Gtk.TargetEntry [] {
+				new Gtk.TargetEntry ("text/uri-list", 0, 0),
+				new Gtk.TargetEntry ("_NETSCAPE_URL", 0, 0)
+			};
 
-			Gtk.Drag.DestSet (this, 
-					  Gtk.DestDefaults.All, 
-					  targets,
-					  Gdk.DragAction.Copy);
+			Gtk.Drag.DestSet (this,
+			                  Gtk.DestDefaults.All,
+			                  targets,
+			                  Gdk.DragAction.Copy);
 
 			DragDataReceived += OnDragDataReceived;
 		}
 
 		// Pop up Start Here and insert dropped links, in the form:
-		//	Wednesday, December 8, 6:45 AM
-		//	http://luna/kwiki/index.cgi?AdelaideUniThoughts
-		//	http://www.beatniksoftware.com/blog/
+		// Wednesday, December 8, 6:45 AM
+		// http://luna/kwiki/index.cgi?AdelaideUniThoughts
+		// http://www.beatniksoftware.com/blog/
 		// And select the inserted text.
 		//
 		// FIXME: Make undoable, make sure our date-sizing tag never "bleeds".
@@ -420,23 +454,23 @@ namespace Tomboy
 				if (more_than_one)
 					insert_text.Append ("\n");
 
-				if (uri.IsFile) 
+				if (uri.IsFile)
 					insert_text.Append (uri.LocalPath);
 				else
 					insert_text.Append (uri.ToString ());
 
 				more_than_one = true;
 			}
-			
+
 			Note link_note = manager.FindByUri (NoteManager.StartNoteUri);
 			if (link_note != null) {
 				link_note.Window.Present ();
-				PrependTimestampedText (link_note, 
-							DateTime.Now, 
-							insert_text.ToString ());
+				PrependTimestampedText (link_note,
+				                        DateTime.Now,
+				                        insert_text.ToString ());
 			}
 		}
-		
+
 		void InitPixbuf ()
 		{
 			// For some reason, the first time we ask for the allocation,
@@ -445,7 +479,7 @@ namespace Tomboy
 			// to be called again anyhow.
 			if (panel_size < 16)
 				panel_size = 16;
-			
+
 			// Control specifically which icon is used at the smaller sizes
 			// so that no scaling occurs.  In the case of the panel applet,
 			// add a couple extra pixels of padding so it matches the behavior
@@ -453,7 +487,7 @@ namespace Tomboy
 			// info.
 			int icon_size = panel_size;
 			if (Tomboy.IsPanelApplet)
-				icon_size = panel_size - 2;	// padding
+				icon_size = panel_size - 2; // padding
 			if (icon_size <= 21)
 				icon_size = 16;
 			else if (icon_size <= 31)
@@ -464,7 +498,7 @@ namespace Tomboy
 			Gdk.Pixbuf new_icon = GuiUtils.GetIcon ("tomboy", icon_size);
 			image.Pixbuf = new_icon;
 		}
-		
+
 		///
 		/// Determine whether the tray is inside a horizontal or vertical
 		/// panel so the size of the icon can adjust correctly.
@@ -474,13 +508,13 @@ namespace Tomboy
 			if (this.ParentWindow == null) {
 				return PanelOrientation.Horizontal;
 			}
-			
+
 			Gdk.Window top_level_window = this.ParentWindow.Toplevel;
-			
+
 			Gdk.Rectangle rect = top_level_window.FrameExtents;
 			if (rect.Width < rect.Height)
 				return PanelOrientation.Vertical;
-			
+
 			return PanelOrientation.Horizontal;
 		}
 
@@ -492,20 +526,20 @@ namespace Tomboy
 			if (GetPanelOrientation () == PanelOrientation.Horizontal) {
 				if (panel_size == Allocation.Height)
 					return;
-				
+
 				panel_size = Allocation.Height;
 			} else {
 				if (panel_size == Allocation.Width)
 					return;
-				
+
 				panel_size = Allocation.Width;
 			}
-			
+
 			InitPixbuf ();
 		}
 	}
 
-	// 
+	//
 	// This is a helper to take the XKeybinding string from GConf, and
 	// convert it to a widget accelerator label, so note menu items can
 	// display their global X keybinding.
@@ -527,9 +561,9 @@ namespace Tomboy
 		{
 			try {
 				string binding = (string) Preferences.Get (gconf_path);
-				if (binding == null || 
-				    binding == String.Empty || 
-				    binding == "disabled")
+				if (binding == null ||
+				                binding == String.Empty ||
+				                binding == "disabled")
 					return null;
 
 				binding = binding.Replace ("<", "");
@@ -537,63 +571,63 @@ namespace Tomboy
 
 				return binding;
 			} catch {
-				return null;
-			}
+			return null;
 		}
+	}
 
-		[DllImport("libtomboy")]
+	[DllImport("libtomboy")]
 		static extern bool egg_accelerator_parse_virtual (string keystring,
-								  out uint keysym,
-								  out uint virtual_mods);
+			                out uint keysym,
+			                out uint virtual_mods);
 
 		[DllImport("libtomboy")]
 		static extern void egg_keymap_resolve_virtual_modifiers (
-			IntPtr keymap,
-			uint virtual_mods,
-			out Gdk.ModifierType real_mods);
+			        IntPtr keymap,
+			        uint virtual_mods,
+			        out Gdk.ModifierType real_mods);
 
-		public static bool GetAccelKeys (string               gconf_path, 
-						 out uint             keyval, 
-						 out Gdk.ModifierType mods)
+		public static bool GetAccelKeys (string               gconf_path,
+		                                 out uint             keyval,
+		                                 out Gdk.ModifierType mods)
 		{
 			keyval = 0;
 			mods = 0;
 
 			try {
 				string binding = (string) Preferences.Get (gconf_path);
-				if (binding == null || 
-				    binding == String.Empty || 
-				    binding == "disabled")
+				if (binding == null ||
+				                binding == String.Empty ||
+				                binding == "disabled")
 					return false;
 
 				uint virtual_mods = 0;
 				if (!egg_accelerator_parse_virtual (binding,
-								    out keyval,
-								    out virtual_mods))
+				                                    out keyval,
+				                                    out virtual_mods))
 					return false;
 
 				Gdk.Keymap keymap = Gdk.Keymap.Default;
 				egg_keymap_resolve_virtual_modifiers (keymap.Handle,
-								      virtual_mods,
-								      out mods);
+				                                      virtual_mods,
+				                                      out mods);
 
 				return true;
 			} catch {
-				return false;
-			}
+			return false;
 		}
+	}
 
-		public static void AddAccelerator (Gtk.MenuItem item, string gconf_path)
+	public static void AddAccelerator (Gtk.MenuItem item, string gconf_path)
 		{
 			uint keyval;
 			Gdk.ModifierType mods;
 
 			if (GetAccelKeys (gconf_path, out keyval, out mods))
 				item.AddAccelerator ("activate",
-						     accel_group,
-						     keyval,
-						     mods,
-						     Gtk.AccelFlags.Visible);
+				                     accel_group,
+				                     keyval,
+				                     mods,
+				                     Gtk.AccelFlags.Visible);
 		}
 	}
 }
