@@ -11,12 +11,12 @@ using Mono.Unix.Native;
 
 namespace Tomboy
 {
-	public class GuiUtils 
+	public class GuiUtils
 	{
-		static void GetMenuPosition (Gtk.Menu menu, 
-					     out int  x, 
-					     out int  y, 
-					     out bool push_in)
+		static void GetMenuPosition (Gtk.Menu menu,
+		                             out int  x,
+		                             out int  y,
+		                             out bool push_in)
 		{
 			menu.AttachWidget.GdkWindow.GetOrigin (out x, out y);
 			x += menu.AttachWidget.Allocation.X;
@@ -37,7 +37,7 @@ namespace Tomboy
 			// delegate when calling Gtk.Menu.AttachToWidget.
 		}
 
-		static void DeactivateMenu (object sender, EventArgs args) 
+		static void DeactivateMenu (object sender, EventArgs args)
 		{
 			Gtk.Menu menu = (Gtk.Menu) sender;
 			menu.Popdown ();
@@ -53,18 +53,18 @@ namespace Tomboy
 		public static void PopupMenu (Gtk.Menu menu, Gdk.EventButton ev)
 		{
 			menu.Deactivated += DeactivateMenu;
-			menu.Popup (null, 
-				    null, 
-				    new Gtk.MenuPositionFunc (GetMenuPosition), 
-				    (ev == null) ? 0 : ev.Button, 
-				    (ev == null) ? Gtk.Global.CurrentEventTime : ev.Time);
+			menu.Popup (null,
+			            null,
+			            new Gtk.MenuPositionFunc (GetMenuPosition),
+			            (ev == null) ? 0 : ev.Button,
+			            (ev == null) ? Gtk.Global.CurrentEventTime : ev.Time);
 
 			// Highlight the parent
 			if (menu.AttachWidget != null)
 				menu.AttachWidget.State = Gtk.StateType.Selected;
 		}
 
-		public static Gdk.Pixbuf GetIcon (string resource_name, int size) 
+		public static Gdk.Pixbuf GetIcon (string resource_name, int size)
 		{
 			try {
 				return Gtk.IconTheme.Default.LoadIcon (resource_name, size, 0);
@@ -94,7 +94,7 @@ namespace Tomboy
 
 			button.Add (align);
 			return button;
-		}			
+		}
 
 		public static Gtk.Button MakeImageButton (string stock_id, string label)
 		{
@@ -102,36 +102,36 @@ namespace Tomboy
 			return MakeImageButton (image, label);
 		}
 
-		public static void ShowHelp (string filename, 
-					     string link_id, 
-					     Gdk.Screen screen, 
-					     Gtk.Window parent)
+		public static void ShowHelp (string filename,
+		                             string link_id,
+		                             Gdk.Screen screen,
+		                             Gtk.Window parent)
 		{
 			try {
 				Gnome.Help.DisplayDesktopOnScreen (
-					Gnome.Program.Get (),
-					Defines.GNOME_HELP_DIR,
-					filename, 
-					link_id, 
-					screen);
+				        Gnome.Program.Get (),
+				        Defines.GNOME_HELP_DIR,
+				        filename,
+				        link_id,
+				        screen);
 			} catch {
-				string message = 
-					Catalog.GetString ("The \"Tomboy Notes Manual\" could " +
-							   "not be found.  Please verify " +
-							   "that your installation has been " +
-							   "completed successfully.");
-				HIGMessageDialog dialog = 
-					new HIGMessageDialog (parent,
-							      Gtk.DialogFlags.DestroyWithParent,
-							      Gtk.MessageType.Error,
-							      Gtk.ButtonsType.Ok,
-							      Catalog.GetString ("Help not found"),
-							      message);
+			string message =
+			Catalog.GetString ("The \"Tomboy Notes Manual\" could " +
+			"not be found.  Please verify " +
+			"that your installation has been " +
+			"completed successfully.");
+				HIGMessageDialog dialog =
+				        new HIGMessageDialog (parent,
+				                              Gtk.DialogFlags.DestroyWithParent,
+				                              Gtk.MessageType.Error,
+				                              Gtk.ButtonsType.Ok,
+				                              Catalog.GetString ("Help not found"),
+				                              message);
 				dialog.Run ();
 				dialog.Destroy ();
 			}
 		}
-		
+
 		/// <summary>
 		/// Get a string that is more friendly/pretty for the specified date.
 		/// For example, "Today, 3:00 PM", "4 days ago, 9:20 AM".
@@ -148,56 +148,56 @@ namespace Tomboy
 			if (date.Year == now.Year) {
 				if (date.DayOfYear == now.DayOfYear)
 					pretty_str = show_time ?
-						String.Format (Catalog.GetString ("Today, {0}"), 
-							      short_time) :
-						Catalog.GetString ("Today");
+					             String.Format (Catalog.GetString ("Today, {0}"),
+					                            short_time) :
+					             Catalog.GetString ("Today");
 				else if (date.DayOfYear < now.DayOfYear
-							&& date.DayOfYear == now.DayOfYear - 1)
+				                && date.DayOfYear == now.DayOfYear - 1)
 					pretty_str = show_time ?
-						String.Format (Catalog.GetString ("Yesterday, {0}"),
-									short_time) :
-						Catalog.GetString ("Yesterday");
+					             String.Format (Catalog.GetString ("Yesterday, {0}"),
+					                            short_time) :
+					             Catalog.GetString ("Yesterday");
 				else if (date.DayOfYear < now.DayOfYear
-							&& date.DayOfYear > now.DayOfYear - 6)
+				                && date.DayOfYear > now.DayOfYear - 6)
 					pretty_str = show_time ?
-						String.Format (Catalog.GetString ("{0} days ago, {1}"),
-							now.DayOfYear - date.DayOfYear, short_time) :
-						String.Format (Catalog.GetString ("{0} days ago"),
-							now.DayOfYear - date.DayOfYear);
+					             String.Format (Catalog.GetString ("{0} days ago, {1}"),
+					                            now.DayOfYear - date.DayOfYear, short_time) :
+					             String.Format (Catalog.GetString ("{0} days ago"),
+					                            now.DayOfYear - date.DayOfYear);
 				else if (date.DayOfYear > now.DayOfYear
-							&& date.DayOfYear == now.DayOfYear + 1)
+				                && date.DayOfYear == now.DayOfYear + 1)
 					pretty_str = show_time ?
-						String.Format (Catalog.GetString ("Tomorrow, {0}"),
-									short_time) :
-						Catalog.GetString ("Tomorrow");
+					             String.Format (Catalog.GetString ("Tomorrow, {0}"),
+					                            short_time) :
+					             Catalog.GetString ("Tomorrow");
 				else if (date.DayOfYear > now.DayOfYear
-							&& date.DayOfYear < now.DayOfYear + 6)
+				                && date.DayOfYear < now.DayOfYear + 6)
 					pretty_str = show_time ?
-						String.Format (Catalog.GetString ("In {0} days, {1}"),
-							date.DayOfYear - now.DayOfYear, short_time) :
-						String.Format (Catalog.GetString ("In {0} days"),
-							date.DayOfYear - now.DayOfYear);
+					             String.Format (Catalog.GetString ("In {0} days, {1}"),
+					                            date.DayOfYear - now.DayOfYear, short_time) :
+					             String.Format (Catalog.GetString ("In {0} days"),
+					                            date.DayOfYear - now.DayOfYear);
 				else
 					pretty_str = show_time ?
-						date.ToString (Catalog.GetString ("MMMM d, h:mm tt")) :
-						date.ToString (Catalog.GetString ("MMMM d"));
+					             date.ToString (Catalog.GetString ("MMMM d, h:mm tt")) :
+					             date.ToString (Catalog.GetString ("MMMM d"));
 			} else if (date == DateTime.MinValue)
 				pretty_str = Catalog.GetString ("No Date");
 			else
 				pretty_str = show_time ?
-					date.ToString (Catalog.GetString ("MMMM d yyyy, h:mm tt")) :
-					date.ToString (Catalog.GetString ("MMMM d yyyy"));
-				
+				             date.ToString (Catalog.GetString ("MMMM d yyyy, h:mm tt")) :
+				             date.ToString (Catalog.GetString ("MMMM d yyyy"));
+
 			return pretty_str;
 		}
 	}
 
-	public class GlobalKeybinder 
+	public class GlobalKeybinder
 	{
 		Gtk.AccelGroup accel_group;
 		Gtk.Menu fake_menu;
 
-		public GlobalKeybinder (Gtk.AccelGroup accel_group) 
+		public GlobalKeybinder (Gtk.AccelGroup accel_group)
 		{
 			this.accel_group = accel_group;
 
@@ -206,17 +206,17 @@ namespace Tomboy
 		}
 
 		public void AddAccelerator (EventHandler handler,
-					    uint key,
-					    Gdk.ModifierType modifiers,
-					    Gtk.AccelFlags flags)
+		                            uint key,
+		                            Gdk.ModifierType modifiers,
+		                            Gtk.AccelFlags flags)
 		{
 			Gtk.MenuItem foo = new Gtk.MenuItem ();
 			foo.Activated += handler;
 			foo.AddAccelerator ("activate",
-					    accel_group,
-					    key, 
-					    modifiers,
-					    flags);
+			                    accel_group,
+			                    key,
+			                    modifiers,
+			                    flags);
 			foo.Show ();
 
 			fake_menu.Append (foo);
@@ -228,12 +228,12 @@ namespace Tomboy
 		Gtk.AccelGroup accel_group;
 
 		public HIGMessageDialog (Gtk.Window parent,
-					 Gtk.DialogFlags flags,
-					 Gtk.MessageType type,
-					 Gtk.ButtonsType buttons,
-					 string          header,
-					 string          msg)
-			: base ()
+		                         Gtk.DialogFlags flags,
+		                         Gtk.MessageType type,
+		                         Gtk.ButtonsType buttons,
+		                         string          header,
+		                         string          msg)
+: base ()
 		{
 			HasSeparator = false;
 			BorderWidth = 5;
@@ -255,34 +255,34 @@ namespace Tomboy
 
 			switch (type) {
 			case Gtk.MessageType.Error:
-				image = new Gtk.Image (Gtk.Stock.DialogError, 
-						       Gtk.IconSize.Dialog);
+				image = new Gtk.Image (Gtk.Stock.DialogError,
+				                       Gtk.IconSize.Dialog);
 				break;
 			case Gtk.MessageType.Question:
-				image = new Gtk.Image (Gtk.Stock.DialogQuestion, 
-						       Gtk.IconSize.Dialog);
+				image = new Gtk.Image (Gtk.Stock.DialogQuestion,
+				                       Gtk.IconSize.Dialog);
 				break;
 			case Gtk.MessageType.Info:
-				image = new Gtk.Image (Gtk.Stock.DialogInfo, 
-						       Gtk.IconSize.Dialog);
+				image = new Gtk.Image (Gtk.Stock.DialogInfo,
+				                       Gtk.IconSize.Dialog);
 				break;
 			case Gtk.MessageType.Warning:
-				image = new Gtk.Image (Gtk.Stock.DialogWarning, 
-						       Gtk.IconSize.Dialog);
+				image = new Gtk.Image (Gtk.Stock.DialogWarning,
+				                       Gtk.IconSize.Dialog);
 				break;
 			}
 
 			image.Show ();
 			image.Yalign = 0;
 			hbox.PackStart (image, false, false, 0);
-			
+
 			Gtk.VBox label_vbox = new Gtk.VBox (false, 0);
 			label_vbox.Show ();
 			hbox.PackStart (label_vbox, true, true, 0);
 
 			string title = String.Format ("<span weight='bold' size='larger'>{0}" +
-						      "</span>\n",
-						      header);
+			                              "</span>\n",
+			                              header);
 
 			Gtk.Label label;
 
@@ -301,7 +301,7 @@ namespace Tomboy
 			label.SetAlignment (0.0f, 0.5f);
 			label.Show ();
 			label_vbox.PackStart (label, false, false, 0);
-			
+
 			switch (buttons) {
 			case Gtk.ButtonsType.None:
 				break;
@@ -345,28 +345,28 @@ namespace Tomboy
 			if (is_default) {
 				DefaultResponse = response;
 				button.AddAccelerator ("activate",
-						       accel_group,
-						       (uint) Gdk.Key.Escape, 
-						       0,
-						       Gtk.AccelFlags.Visible);
+				                       accel_group,
+				                       (uint) Gdk.Key.Escape,
+				                       0,
+				                       Gtk.AccelFlags.Visible);
 			}
 		}
 	}
 
-	public class UriList : ArrayList 
+	public class UriList : ArrayList
 	{
-		public UriList (Note [] notes) 
+		public UriList (Note [] notes)
 		{
 			foreach (Note note in notes) {
 				try {
 					Uri uri = new Uri (note.Uri);
 					Add (uri);
 				} catch {
-				}
 			}
 		}
+	}
 
-		private void LoadFromString (string data) 
+	private void LoadFromString (string data)
 		{
 			string [] items = data.Split ('\n');
 
@@ -388,23 +388,23 @@ namespace Tomboy
 					if (uri != null)
 						Add (uri);
 				} catch {
-				}
 			}
 		}
+	}
 
-		public UriList (string data) 
+	public UriList (string data)
 		{
 			LoadFromString (data);
 		}
 
-		public UriList (Gtk.SelectionData selection) 
+		public UriList (Gtk.SelectionData selection)
 		{
 			// FIXME this should check the atom etc.
 			if (selection.Length > 0)
 				LoadFromString (Encoding.UTF8.GetString (selection.Data));
 		}
 
-		public override string ToString () 
+		public override string ToString ()
 		{
 			StringBuilder list = new StringBuilder ();
 
@@ -415,7 +415,7 @@ namespace Tomboy
 			return list.ToString ();
 		}
 
-		public string [] GetLocalPaths () 
+		public string [] GetLocalPaths ()
 		{
 			int count = 0;
 			foreach (Uri uri in this) {
@@ -436,7 +436,7 @@ namespace Tomboy
 	}
 
 	// Encode xml entites
-	public class XmlEncoder 
+	public class XmlEncoder
 	{
 		static StringBuilder builder;
 		static StringWriter writer;
@@ -460,7 +460,7 @@ namespace Tomboy
 	}
 
 	// Strip xml tags
-	public class XmlDecoder 
+	public class XmlDecoder
 	{
 		static StringBuilder builder;
 
@@ -498,8 +498,8 @@ namespace Tomboy
 		Gtk.TextMark start_mark;
 		Gtk.TextMark end_mark;
 
-		public TextRange (Gtk.TextIter start, 
-				  Gtk.TextIter end)
+		public TextRange (Gtk.TextIter start,
+		                  Gtk.TextIter end)
 		{
 			if (start.Buffer != end.Buffer)
 				throw new Exception ("Start buffer and end buffer do not match");
@@ -511,29 +511,43 @@ namespace Tomboy
 
 		public Gtk.TextBuffer Buffer
 		{
-			get { return buffer; }
+			get {
+				return buffer;
+			}
 		}
 
 		public string Text
 		{
-			get { return Start.GetText (End); }
+			get {
+				return Start.GetText (End);
+			}
 		}
 
 		public int Length
 		{
-			get { return Text.Length; }
+			get {
+				return Text.Length;
+			}
 		}
 
 		public Gtk.TextIter Start
 		{
-			get { return buffer.GetIterAtMark (start_mark); }
-			set { buffer.MoveMark (start_mark, value); }
+			get {
+				return buffer.GetIterAtMark (start_mark);
+			}
+			set {
+				buffer.MoveMark (start_mark, value);
+			}
 		}
 
 		public Gtk.TextIter End
 		{
-			get { return buffer.GetIterAtMark (end_mark); }
-			set { buffer.MoveMark (end_mark, value); }
+			get {
+				return buffer.GetIterAtMark (end_mark);
+			}
+			set {
+				buffer.MoveMark (end_mark, value);
+			}
 		}
 
 		public void Erase ()
@@ -563,7 +577,7 @@ namespace Tomboy
 		TextRange range;
 
 		public TextTagEnumerator (Gtk.TextBuffer buffer, string tag_name)
-			: this (buffer, buffer.TagTable.Lookup (tag_name))
+: this (buffer, buffer.TagTable.Lookup (tag_name))
 		{
 		}
 
@@ -577,8 +591,10 @@ namespace Tomboy
 		}
 
 		public object Current
-		{ 
-			get { return range; }
+		{
+			get {
+				return range;
+			}
 		}
 
 		// FIXME: Mutability bugs.  multiple Links on the same line
@@ -653,8 +669,8 @@ namespace Tomboy
 		{
 			Cancel ();
 			this.args = args;
-			timeout_id = GLib.Timeout.Add (timeout_millis, 
-						       new GLib.TimeoutHandler (TimeoutExpired));
+			timeout_id = GLib.Timeout.Add (timeout_millis,
+			                               new GLib.TimeoutHandler (TimeoutExpired));
 		}
 
 		public void Cancel ()
@@ -681,7 +697,7 @@ namespace Tomboy
 	public class ForcedPresentWindow : Gtk.Window
 	{
 		public ForcedPresentWindow (string name)
-			: base (name)
+: base (name)
 		{
 		}
 
@@ -705,21 +721,21 @@ namespace Tomboy
 		Gtk.VBox box_vert;
 		Gtk.HBox box_horiz;
 
-		public ToolMenuButton (Gtk.Toolbar toolbar, 
-				       string stock_image, 
-				       string label, 
-				       Gtk.Menu menu)
-			: this (toolbar, 
-				new Gtk.Image (stock_image, toolbar.IconSize), 
-				label,
-				menu)
+		public ToolMenuButton (Gtk.Toolbar toolbar,
+		                       string stock_image,
+		                       string label,
+		                       Gtk.Menu menu)
+: this (toolbar,
+		        new Gtk.Image (stock_image, toolbar.IconSize),
+		        label,
+		        menu)
 		{
 		}
 
-		public ToolMenuButton (Gtk.Toolbar toolbar, 
-				       Gtk.Image image, 
-				       string label, 
-				       Gtk.Menu menu)
+		public ToolMenuButton (Gtk.Toolbar toolbar,
+		                       Gtk.Image image,
+		                       string label,
+		                       Gtk.Menu menu)
 		{
 			this.CanFocus = true;
 			this.Relief = toolbar.ReliefStyle;
@@ -751,14 +767,14 @@ namespace Tomboy
 			toolbar.StyleChanged += OnToolbarStyleChanged;
 		}
 
-		protected override bool OnButtonPressEvent (Gdk.EventButton ev) 
+		protected override bool OnButtonPressEvent (Gdk.EventButton ev)
 		{
 			GuiUtils.PopupMenu (menu, ev);
 			Active = true;
 			return true;
 		}
 
-		protected override void OnActivated () 
+		protected override void OnActivated ()
 		{
 			menu.SelectFirst (true);
 			GuiUtils.PopupMenu (menu, null);
@@ -779,7 +795,7 @@ namespace Tomboy
 			return true;
 		}
 
-		void ReleaseButton (object sender, EventArgs args) 
+		void ReleaseButton (object sender, EventArgs args)
 		{
 			// Release the state when the menu closes
 			Active = false;
@@ -838,49 +854,49 @@ namespace Tomboy
 		static Gnome.Program program;
 		static ActionManager action_manager;
 
-		public static void Initialize (string locale_dir, 
-					       string display_name, 
-					       string process_name,  
-					       string [] args)
+		public static void Initialize (string locale_dir,
+		                               string display_name,
+		                               string process_name,
+		                               string [] args)
 		{
 			try {
 				SetProcessName (process_name);
 			} catch {} // Ignore exception if fail (not needed to run)
 
 			Gtk.Application.Init ();
-			program = new Gnome.Program ("Tomboy", 
-						     Defines.VERSION, 
-						     Gnome.Modules.UI, 
-						     args);
-			
+			program = new Gnome.Program ("Tomboy",
+			                             Defines.VERSION,
+			                             Gnome.Modules.UI,
+			                             args);
+
 			action_manager = new ActionManager ();
 			action_manager.LoadInterface ();
 
 			RegisterSignalHandlers ();
-			
+
 			// Register handler for saving session when logging out of Gnome
 			Gnome.Client client = Gnome.Global.MasterClient ();
 			client.SaveYourself += OnSaveYourself;
 		}
 
 		[DllImport("libc")]
-		private static extern int prctl (int option, 
-						 byte [] arg2, 
-						 IntPtr arg3, 
-						 IntPtr arg4, 
-						 IntPtr arg5);
+		private static extern int prctl (int option,
+			                                 byte [] arg2,
+			                                 IntPtr arg3,
+			                                 IntPtr arg4,
+			                                 IntPtr arg5);
 
 		// From Banshee: Banshee.Base/Utilities.cs
 		public static void SetProcessName (string name)
 		{
-			if (prctl (15 /* PR_SET_NAME */, 
-				   Encoding.ASCII.GetBytes (name + "\0"),
-				   IntPtr.Zero, 
-				   IntPtr.Zero, 
-				   IntPtr.Zero) != 0)
+			if (prctl (15 /* PR_SET_NAME */,
+			                Encoding.ASCII.GetBytes (name + "\0"),
+			                IntPtr.Zero,
+			                IntPtr.Zero,
+			                IntPtr.Zero) != 0)
 				throw new ApplicationException (
-					"Error setting process name: " +
-					Mono.Unix.Native.Stdlib.GetLastError ());
+				        "Error setting process name: " +
+				        Mono.Unix.Native.Stdlib.GetLastError ());
 		}
 
 		static void RegisterSignalHandlers ()
@@ -894,22 +910,22 @@ namespace Tomboy
 		static void OnSaveYourself (object sender, Gnome.SaveYourselfArgs args)
 		{
 			Logger.Log ("Received request for saving session");
-			
+
 			if (ExitingEvent != null)
 				ExitingEvent (null, new EventArgs ());
 		}
 
 		public static void RegisterSessionManagerRestart (string executable_path,
-								  string[] args, 
-								  string[] environment)
+		                string[] args,
+		                string[] environment)
 		{
 			if (executable_path == null)
 				return;
 
 			// Restart if we are running when the session ends or at crash...
 			Gnome.Client client = Gnome.Global.MasterClient ();
-			client.RestartStyle = 
-				Gnome.RestartStyle.IfRunning | Gnome.RestartStyle.Immediately;
+			client.RestartStyle =
+			        Gnome.RestartStyle.IfRunning | Gnome.RestartStyle.Immediately;
 			client.Die += OnSessionManagerDie;
 
 			foreach (string env in environment) {
@@ -919,8 +935,8 @@ namespace Tomboy
 				}
 			}
 
-			// Get the args for session restart... 	 
-			string [] restart_args = new string [args.Length + 1]; 	 
+			// Get the args for session restart...
+			string [] restart_args = new string [args.Length + 1];
 			restart_args [0] = executable_path;
 			args.CopyTo (restart_args, 1);
 			client.SetRestartCommand (restart_args.Length, restart_args);
@@ -969,10 +985,12 @@ namespace Tomboy
 		{
 			Gtk.Main.Quit ();
 		}
-		
+
 		public static ActionManager ActionManager
 		{
-			get { return action_manager; }
+			get {
+				return action_manager;
+			}
 		}
 	}
 }
